============================
PaperCut XML WebServices API
============================

.. image:: https://img.shields.io/pypi/v/papercut_xml_webservices_api.svg
    :target: https://pypi.python.org/pypi/papercut_xml_webservices_api

-  Free software: MIT license
-   `Documentation <https://github.com/safehome-jdev/PaperCutSoftware/blob/main/api/papercut_xml_webservices_api/README.md>`__
-  `PaperCut API Docs <https://www.papercut.com/help/manuals/ng-mf/common/tools-web-services/>`__

Credits
-------

This package was created with `Cookiecutter <https://github.com/audreyr/cookiecutter>`___ and the `audreyr/cookiecutter-pypackage <https://github.com/audreyr/cookiecutter-pypackage>`__ project template.